@@ -2,7 +2,7 @@ pub mod chunk;
 pub(crate) mod chunk_queue;
 pub(crate) mod conn;
 pub(crate) mod conn_map;
-pub mod errors;
+pub mod error;
 pub mod interface;
 pub mod nat;
 pub mod net;
